;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "window-purpose" "20241207.148"
  "Purpose-based window management for Emacs."
  '((emacs      "25.1")
    (let-alist  "1.0.3")
    (imenu-list "0.1"))
  :url "https://github.com/bmag/emacs-purpose"
  :commit "c827f45cd9b278b3eb9c2f4bcb55ef2fca5d3048"
  :revdesc "c827f45cd9b2"
  :keywords '("frames"))
